componenttools.list_improper_contents_of_component_that_cross_prolated_offset
=============================================================================

.. autofunction:: abjad.tools.componenttools.list_improper_contents_of_component_that_cross_prolated_offset.list_improper_contents_of_component_that_cross_prolated_offset
